pecos.error\_models.simple\_depolarizing\_error\_model
======================================================

.. automodule:: pecos.error_models.simple_depolarizing_error_model











   .. rubric:: Classes

   .. autosummary::

      SimpleDepolarizingErrorModel
